package com.dmolinerm.sac.BLL;

import java.io.BufferedInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;

import android.content.Context;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Color;
import android.net.Uri;
import android.support.v4.widget.CursorAdapter;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;

import com.dmolinerm.sac.R;
import com.dmolinerm.sac.DAO.SacDatabaseHelper;
import com.dmolinerm.sac.GUI.Constantes;
import com.dmolinerm.sac.entity.Picto;

/**
 * @author David Moliner Mateu
 * Adaptador que rellena el listado de frases de un contexto.
 */
public class SacFrasesContextoAdapter extends CursorAdapter{

	private SacDatabaseHelper databaseHelper;
	private ImageView borde1;
	private ImageView image1;
	private ImageView borde2;
	private ImageView image2;
	private ImageView borde3;
	private ImageView image3;
	private ImageView borde4;
	private ImageView image4;
	private Context context;
	
	public SacFrasesContextoAdapter(Context context, Cursor c) {
		super(context, c, CursorAdapter.FLAG_REGISTER_CONTENT_OBSERVER);
		databaseHelper = new SacDatabaseHelper(context);
		this.context = context;
	}

	@Override
	public void bindView(View view, Context context, Cursor cursor) {
		
		borde1 = (ImageView) view.findViewById(R.id.frase_row_borde1);
		image1 = (ImageView) view.findViewById(R.id.frase_row_image1);
		borde2 = (ImageView) view.findViewById(R.id.frase_row_borde2);
		image2 = (ImageView) view.findViewById(R.id.frase_row_image2);
		borde3 = (ImageView) view.findViewById(R.id.frase_row_borde3);
		image3 = (ImageView) view.findViewById(R.id.frase_row_image3);
		borde4 = (ImageView) view.findViewById(R.id.frase_row_borde4);
		image4 = (ImageView) view.findViewById(R.id.frase_row_image4);
		
		inicializaPictos();
		rellenaFrase(cursor.getLong(cursor.getColumnIndex(SacDatabaseHelper.FRASES_COLUMN_ID)));
		
	}

	@Override
	public View newView(Context context, Cursor cursor, ViewGroup parent) {
		
		LayoutInflater inflater = LayoutInflater.from(parent.getContext());
		View view = inflater.inflate(R.layout.frase_row, parent, false);
		return view;
	}
	
	private void rellenaFrase(Long idFrase){
		Long pictoId;
		Picto picto;
		Cursor fraseCursor;
		
		fraseCursor = databaseHelper.getPictosFromFrase(idFrase);
		if (fraseCursor.moveToFirst()) {
		     //Recorremos el cursor hasta que no haya ms registros
		     do {
		    	 pictoId = fraseCursor.getLong(fraseCursor.getColumnIndex(SacDatabaseHelper.FRASES_PICTOS_COLUMN_PICTO));
		    	 picto = databaseHelper.getPictoById(pictoId);
		    	 switch(fraseCursor.getInt(fraseCursor.getColumnIndex(SacDatabaseHelper.FRASES_PICTOS_COLUMN_ORDEN))){
		    	 	case 1: rellenaPicto(borde1, image1, picto);
		    	 		break;
		    	 	case 2: rellenaPicto(borde2, image2, picto);
		    	 		break;
		    	 	case 3: rellenaPicto(borde3, image3, picto);
		    	 		break;
		    	 	case 4: rellenaPicto(borde4, image4, picto);	    	 
		    	 }
		    	 picto = null;
		         
		     } while(fraseCursor.moveToNext());
		}
		fraseCursor.close();
		
	}
	
	private void rellenaPicto(ImageView borde, ImageView image, Picto picto){
		if (picto.getSentimiento()){
			borde.setBackgroundColor(Color.parseColor(Constantes.PICTO_EMOCION_COLOR));
		} else {
			borde.setBackgroundResource(Constantes.CATEGORIA_COLOR.get(picto.getCategoria()));
		}
		
		if (picto.isInternoImg()){
			image.setImageResource(picto.getImage());
		} else {
			try{
			String url = "content://media/external/images/media/" + picto.getImage();
			InputStream is = context.getContentResolver().openInputStream(Uri.parse(url));
			BufferedInputStream bis = new BufferedInputStream(is);
	    	//Bitmap bitmap = BitmapFactory.decodeStream(bis);
			Bitmap bitmap = Constantes.resizeImage(BitmapFactory.decodeStream(bis), 70, 70);
	    	image.setImageBitmap(bitmap);
			} catch (FileNotFoundException e){
				e.printStackTrace();
			}
		}
	}
	
	private void inicializaPictos(){
		borde1.setBackgroundResource(Constantes.CATEGORIA_COLOR.get(Constantes.PICTO_CATEGORIA_SIN));
		image1.setImageResource(R.drawable.fondo_transparente);
		borde2.setBackgroundResource(Constantes.CATEGORIA_COLOR.get(Constantes.PICTO_CATEGORIA_SIN));
		image2.setImageResource(R.drawable.fondo_transparente);
		borde3.setBackgroundResource(Constantes.CATEGORIA_COLOR.get(Constantes.PICTO_CATEGORIA_SIN));
		image3.setImageResource(R.drawable.fondo_transparente);
		borde4.setBackgroundResource(Constantes.CATEGORIA_COLOR.get(Constantes.PICTO_CATEGORIA_SIN));
		image4.setImageResource(R.drawable.fondo_transparente);
	}

}
