package com.dmolinerm.sac.DAO;

import java.io.File;
import java.util.ArrayList;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

import com.dmolinerm.sac.R;
import com.dmolinerm.sac.GUI.Constantes;
import com.dmolinerm.sac.entity.Contexto;
import com.dmolinerm.sac.entity.Frase;
import com.dmolinerm.sac.entity.Picto;

/**
 * @author David Moliner Mateu
 * representa la capa de acceso a datos.
 * Todas las operaciones sobre la base de datos se realizan aqu.
 */
public class SacDatabaseHelper {
	
	// NOMBRE Y VERSION DE LA BASE DE DATOS
	private static final int DATABASE_VERSION = 1;
	private static final String DATABASE_NAME = "sac.db";
	
	// TABLA PICTOS
	private static final String PICTOS_TABLE_NAME = "pictos";
	public static final String PICTOS_COLUMN_ID = "_id";
	public static final String PICTOS_COLUMN_DESC = "descripcion";
	public static final String PICTOS_COLUMN_IMAGEN = "imagen";
	public static final String PICTOS_COLUMN_EMOCION = "es_emocion";
	public static final String PICTOS_COLUMN_CATEGORIA = "categoria";
	public static final String PICTOS_COLUMN_INTERNO_IMG = "interno_img";
	public static final String PICTOS_COLUMN_LOCUCION = "locucion";
	public static final String PICTOS_COLUMN_INTERNO_LOC = "interno_loc";
	
	// TABLA CONTEXTOS
	private static final String CONTEXTOS_TABLE_NAME = "contextos";
	public static final String CONTEXTOS_COLUMN_ID = "_id";
	public static final String CONTEXTOS_COLUMN_DESC = "descripcion";
	
	// TABLA FRASES
	private static final String FRASES_TABLE_NAME = "frases";
	public static final String FRASES_COLUMN_ID = "_id";
	public static final String FRASES_COLUMN_LOCUCION = "locucion";
	public static final String FRASES_COLUMN_INTERNO_LOC = "interno_loc";
	
	// TABLA PICTO_FRASE
	private static final String FRASES_PICTOS_TABLE_NAME = "picto_frase";
	public static final String FRASES_PICTOS_COLUMN_ID = "_id";
	public static final String FRASES_PICTOS_COLUMN_PICTO = "picto";
	public static final String FRASES_PICTOS_COLUMN_FRASE = "frase";
	public static final String FRASES_PICTOS_COLUMN_ORDEN = "orden";
	
	// TABLA CONTEXTO_FRASE
	private static final String FRASES_CONTEXTOS_TABLE_NAME = "contexto_frase";
	public static final String FRASES_CONTEXTOS_COLUMN_ID = "_id";
	public static final String FRASES_CONTEXTOS_COLUMN_FRASE = "frase";
	public static final String FRASES_CONTEXTOS_COLUMN_CONTEXTO = "contexto";
	
	// TABLA CONT_LOCUCIONES
	private static final String CONTADOR_LOCUCIONES_TABLE_NAME = "cont_locuciones";
	public static final String CONTADOR_LOCUCIONES_COLUMN_ID = "_id";
	public static final String CONTADOR_LOCUCIONES_COLUMN_VALOR = "valor";
	
	private SacOpenHelper openHelper;
	private SQLiteDatabase database;
	
	private Context context;
	
	public SacDatabaseHelper(Context context){
		openHelper = new SacOpenHelper(context);
		this.context = context;
		// Obtenemos una conexin de escritura contra la base de datos.
		database = openHelper.getWritableDatabase();
	}
	
	public void close(){
		database.close();
	}
	
	
	/**
	** OPERACIONES SOBRE LA TABLA PICTOS
	*/
	
	// Comprueba si la tabla est vaca.
	public boolean isPictoVacia(){
		Cursor c = database.rawQuery("Select * from " + PICTOS_TABLE_NAME, null);
		boolean vacia = !(c.getCount() > 0);
		c.close();
		return vacia; 
	}
	
	// Devuelve todos los pictos de la tabla
	public Cursor getAllPictos(){
		return database.rawQuery("SELECT * FROM " + PICTOS_TABLE_NAME, null);
	}
	
	// Devuelve el picto solicitado
	public Picto getPictoById(long id){
		Cursor c = database.rawQuery("SELECT * FROM " + PICTOS_TABLE_NAME
				+ " WHERE " + PICTOS_COLUMN_ID + " = " + id, null);
		c.moveToFirst();
		boolean sentimiento = c.getInt(c.getColumnIndex(PICTOS_COLUMN_EMOCION)) > 0;
		boolean interno_img = c.getInt(c.getColumnIndex(PICTOS_COLUMN_INTERNO_IMG)) > 0;
		boolean interno_loc = c.getInt(c.getColumnIndex(PICTOS_COLUMN_INTERNO_LOC)) > 0;
		Picto p = new Picto(c.getLong(c.getColumnIndex(CONTEXTOS_COLUMN_ID)), c.getInt(c.getColumnIndex(PICTOS_COLUMN_IMAGEN)), 
				c.getString(c.getColumnIndex(PICTOS_COLUMN_DESC)), sentimiento, c.getString(c.getColumnIndex(PICTOS_COLUMN_CATEGORIA)),
				interno_img, c.getString(c.getColumnIndex(PICTOS_COLUMN_LOCUCION)), interno_loc);
		c.close();
		return p;
	}
	
	// devuelve los pictos de la categoria indicada
	public Cursor getCategoriaPictos(String categoria){
		Cursor c = database.rawQuery("SELECT * FROM " + PICTOS_TABLE_NAME + " WHERE "
				+ PICTOS_COLUMN_CATEGORIA + " = '" + categoria + "'", null);		
		return c;
	}
	
	// devuelve los pictos que generan emocin
	public Cursor getEmocionPictos(int limite, int offset){
		Cursor c = database.rawQuery("SELECT * FROM " + PICTOS_TABLE_NAME + " WHERE "
				+ PICTOS_COLUMN_EMOCION + " = " + 1
		+ " LIMIT " + limite + " OFFSET " + offset, null);
		return c;
	}
	
	// devuelve la locucin del picto indicado.
	public String getLocucionFromPicto(long id){
		String locucion = "";
		Cursor c = database.rawQuery("SELECT * FROM " + PICTOS_TABLE_NAME
				+ " WHERE " + PICTOS_COLUMN_ID + " = " + id, null);
		if (c.moveToFirst()){
			locucion = c.getString(c.getColumnIndex(PICTOS_COLUMN_LOCUCION));
		}
		c.close();
		return locucion;
	}
	
	// devuelve el nmero de pictos qque generan emocin
	public int getEmocionPictosQty(){
		int count;
		Cursor c = database.rawQuery("SELECT * FROM " + PICTOS_TABLE_NAME
				+ " WHERE " + PICTOS_COLUMN_EMOCION + " = " + 1, null);
		count = c.getCount();
		c.close();
		return count;
	}
	
	// guarda los datos de un picto.
	public void savePicto(Picto picto){
		ContentValues contentValues = new ContentValues();
		//Relleno contentValues con los datos
		contentValues.put(PICTOS_COLUMN_IMAGEN, picto.getImage());
		contentValues.put(PICTOS_COLUMN_DESC, picto.getNombre());
		if (picto.getSentimiento()){
			contentValues.put(PICTOS_COLUMN_EMOCION, 1);
		} else {
			contentValues.put(PICTOS_COLUMN_EMOCION, 0);
		}
		contentValues.put(PICTOS_COLUMN_CATEGORIA, picto.getCategoria());
		if (picto.isInternoImg()){
			contentValues.put(PICTOS_COLUMN_INTERNO_IMG, 1);
		} else {
			contentValues.put(PICTOS_COLUMN_INTERNO_IMG, 0);
		}
		contentValues.put(PICTOS_COLUMN_LOCUCION, picto.getLocucion());
		if (picto.isInternoLoc()){
			contentValues.put(PICTOS_COLUMN_INTERNO_LOC, 1);
		} else {
			contentValues.put(PICTOS_COLUMN_INTERNO_LOC, 0);
		}
		if (picto.getId() == 0){
			//si el picto no existe, inserto la fila
			database.insert(PICTOS_TABLE_NAME, null, contentValues);	
		} else {
			// si existe, la actualizo
			database.update(PICTOS_TABLE_NAME, contentValues, PICTOS_COLUMN_ID + " = " + picto.getId(), null);
		}				
	}
	
	// elimina el picto indicado
	public void deletePicto(long id){
		database.delete(PICTOS_TABLE_NAME, PICTOS_COLUMN_ID + " = " + id, null);
	}
	
	//devuelve verdadero si la locucion es interna
		public boolean getIsLocucionPictoInterna(long id){
			int interno = 0;
			Cursor c = database.rawQuery("SELECT * FROM " + PICTOS_TABLE_NAME 
					+ " WHERE " + PICTOS_COLUMN_ID + " = " + id, null);
			if (c.moveToFirst()){
				interno = c.getInt(c.getColumnIndex(PICTOS_COLUMN_INTERNO_LOC));
			}
			c.close();
			return (interno > 0);
		}
	

	/**
	 * OPERACIONES SOBRE LA TABLA CONTEXTOS
	 */
	
	// Guarda los datos de un contexto.
	public void saveContexto(Contexto ctx){
		ContentValues cv = new ContentValues();
		
		cv.put(CONTEXTOS_COLUMN_DESC, ctx.getDescripcion());
		database.insert(CONTEXTOS_TABLE_NAME, null, cv);
	}
	
	/**
	 * OPERACIONES SOBRE LA TABLA FRASES 
	 * 
	 */
	
	// devuelve todas las frases
	public Cursor getAllFrases(){
		return database.rawQuery("SELECT * FROM " + FRASES_TABLE_NAME, null);
	}
	
	// devuelve los pictos que forman una frase
	public Cursor getPictosFromFrase(long id){
		String sql = "SELECT * FROM " + FRASES_PICTOS_TABLE_NAME +
				" WHERE " + FRASES_PICTOS_COLUMN_FRASE + " = " + id
				+ " ORDER BY " + FRASES_PICTOS_COLUMN_ORDEN;
		return database.rawQuery(sql, null);
	}
	
	// devuelve los contextos a los que est asignada una frase
	public Cursor getContextosFromFrase(long id){
		String sql = "SELECT * FROM " + FRASES_CONTEXTOS_TABLE_NAME +
				" WHERE " + FRASES_CONTEXTOS_COLUMN_FRASE + " = " + id;
		return database.rawQuery(sql, null);
	}
	
	// devuelve la locucin correspondiente a una frase
	public String getLocucionFromFrase(long id){
		String locucion = "";
		Cursor c = database.rawQuery("SELECT * FROM " + FRASES_TABLE_NAME
				+ " WHERE " + FRASES_COLUMN_ID + " = " + id, null);
		if (c.moveToFirst()){
			locucion = c.getString(c.getColumnIndex(FRASES_COLUMN_LOCUCION));
		}
		c.close();
		return locucion;
	}
	
	//devuelve verdadero si la locucion es interna
	public boolean getIsLocucionFraseInterna(long id){
		int interno = 0;
		Cursor c = database.rawQuery("SELECT * FROM " + FRASES_TABLE_NAME 
				+ " WHERE " + FRASES_COLUMN_ID + " = " + id, null);
		if (c.moveToFirst()){
			interno = c.getInt(c.getColumnIndex(FRASES_COLUMN_INTERNO_LOC));
		}
		c.close();
		return (interno > 0);
	}
	
	// guarda los datos de una frase
	public void saveFrase(Frase s){
		ContentValues cvFrase = new ContentValues();
		
		//Crea o Modifica la frase
		cvFrase.put(FRASES_COLUMN_LOCUCION, s.getLocucion());
		if (s.isInternoLoc()){
			cvFrase.put(FRASES_COLUMN_INTERNO_LOC, 1);
		} else {
			cvFrase.put(FRASES_COLUMN_INTERNO_LOC, 0);
		}
		if (s.getId() == 0){
			s.setId(database.insert(FRASES_TABLE_NAME, null, cvFrase));
		} else {
			database.update(FRASES_TABLE_NAME, cvFrase, FRASES_COLUMN_ID + " = " + s.getId(), null);
		}
		
		//Elimina los pictos asociados y los vuelve a crear con las posibles modificaciones
		database.delete(FRASES_PICTOS_TABLE_NAME, FRASES_PICTOS_COLUMN_FRASE + " = " + s.getId(), null);
		if (s.getPicto1() != null){
			insertPictoFrase(s.getPicto1().getId(), s.getId(), 1);
		}
		if (s.getPicto2() != null){
			insertPictoFrase(s.getPicto2().getId(), s.getId(), 2);
		}
		if (s.getPicto3() != null){
			insertPictoFrase(s.getPicto3().getId(), s.getId(), 3);
		}
		if (s.getPicto4() != null){
			insertPictoFrase(s.getPicto4().getId(), s.getId(), 4);
		}
		
		// Elimina los contextos asociados y los vuelve a crear con las posibles modificaciones.
		database.delete(FRASES_CONTEXTOS_TABLE_NAME,FRASES_CONTEXTOS_COLUMN_FRASE + " = " + s.getId(), null);
		if (s.isCasa()){
			insertContextoFrase(Constantes.CONTEXTO_CASA_ID,s.getId());
		}
		if (s.isCalle()){
			insertContextoFrase(Constantes.CONTEXTO_CALLE_ID,s.getId());
		}
		if (s.isColegio()){
			insertContextoFrase(Constantes.CONTEXTO_COLEGIO_ID, s.getId());
		}
	}
	
	// elimina una frase
	public void deleteFrase(long id){
		String locucion = getLocucionFromFrase(id);
		
		// elimina la asignacion de contextos
		database.execSQL("DELETE FROM " + FRASES_CONTEXTOS_TABLE_NAME + " WHERE " + FRASES_CONTEXTOS_COLUMN_FRASE + " = " + id);
		// elimina la asignacin de pictos
		database.execSQL("DELETE FROM " + FRASES_PICTOS_TABLE_NAME + " WHERE " + FRASES_PICTOS_COLUMN_FRASE + " = " + id);
		// elimina la frase
		database.execSQL("DELETE FROM " + FRASES_TABLE_NAME + " WHERE " + FRASES_COLUMN_ID + " = " + id);

		// elimina el fichero de locucin si lo hay
		if (!locucion.equalsIgnoreCase("")){
			File fichero = new File(context.getExternalFilesDir("locuciones").getAbsolutePath() + "/" + locucion);
			fichero.delete();
		}
		
	}
	
	// devuelve el nmero de frases en las que participa un picto.
	public int getFrasesForPicto(long id){
		int n;
		Cursor c = database.rawQuery("SELECT * FROM " + FRASES_PICTOS_TABLE_NAME
				+ " WHERE " + FRASES_PICTOS_COLUMN_PICTO + " = " + id, null);
		n = c.getCount();
		c.close();
		return n;
	}
	
	// devuelve el nmero de frases asignadas a un contexto.
	public int getFrasesContextoQty(long id){
		int n;
		Cursor c = database.rawQuery("SELECT * FROM " + FRASES_CONTEXTOS_TABLE_NAME
				+ " WHERE " + FRASES_CONTEXTOS_COLUMN_CONTEXTO + " = " + id, null);
		n = c.getCount();
		c.close();
		return n;
	}
	
	// devuelve las frases asignadas a un contexto.
	public Cursor getFrasesContexto(int limite, int offset, long idContexto){

		String sql = "SELECT F.* FROM " + FRASES_TABLE_NAME + " F ,"
				+ FRASES_CONTEXTOS_TABLE_NAME + " CF WHERE F." + FRASES_COLUMN_ID
				+ " = CF." + FRASES_CONTEXTOS_COLUMN_FRASE + " AND CF." + FRASES_CONTEXTOS_COLUMN_CONTEXTO
				+ " = " + idContexto + " LIMIT " + limite + " OFFSET " + offset;
		
		Cursor c = database.rawQuery(sql, null);
		return c;
	}
	
	// Asigna un picto a una frase
	private void insertPictoFrase(long pictoId, long fraseId, int orden){
		ContentValues cv = new ContentValues();
		cv.put(FRASES_PICTOS_COLUMN_PICTO,pictoId);
		cv.put(FRASES_PICTOS_COLUMN_FRASE, fraseId);
		cv.put(FRASES_PICTOS_COLUMN_ORDEN, orden);
		database.insert(FRASES_PICTOS_TABLE_NAME, null, cv);
	}
	
	// asigna un contexto a una frase
	private void insertContextoFrase(long contextoId, long fraseId){
		ContentValues cv = new ContentValues();
		cv.put(FRASES_CONTEXTOS_COLUMN_CONTEXTO, contextoId);
		cv.put(FRASES_CONTEXTOS_COLUMN_FRASE, fraseId);
		database.insert(FRASES_CONTEXTOS_TABLE_NAME, null, cv);
	}
	
	/**
	 * 
	 * Operaciones sobre la tabla CONTADOR_LOCUCIONES
	 */
	
	// devuelve el identificador para una nueva locucin.
	public int getNextLocucion(){
		int valor;
		String sql = "SELECT " + CONTADOR_LOCUCIONES_COLUMN_VALOR
				+ " FROM " + CONTADOR_LOCUCIONES_TABLE_NAME + " WHERE "
				+ CONTADOR_LOCUCIONES_COLUMN_ID + " = 1";
		Cursor c = database.rawQuery(sql, null);
		c.moveToFirst();
		valor = c.getInt(c.getColumnIndex(CONTADOR_LOCUCIONES_COLUMN_VALOR));
		
		sql = "UPDATE " + CONTADOR_LOCUCIONES_TABLE_NAME
				+" SET " + CONTADOR_LOCUCIONES_COLUMN_VALOR + " = "
				+ (valor+1) + " WHERE " + CONTADOR_LOCUCIONES_COLUMN_ID + "= 1";
		
		database.execSQL(sql);
		
		return valor;
		
	}
	
	///
	/// Clase Privada OpenHelper
	///
	private class SacOpenHelper extends SQLiteOpenHelper{
		
		SacOpenHelper(Context context){
			super(context, DATABASE_NAME, null, DATABASE_VERSION);
		}

		// Se ejecuta cuando se crea la base de datos por primera vez.
		@Override
		public void onCreate(SQLiteDatabase db) {
			
			//Crear la tabla PICTOS
			db.execSQL("CREATE TABLE " + PICTOS_TABLE_NAME + "("
					+ PICTOS_COLUMN_ID + " INTEGER PRIMARY KEY, "
					+ PICTOS_COLUMN_DESC + " TEXT, "
					+ PICTOS_COLUMN_IMAGEN + " INTEGER, "
					+ PICTOS_COLUMN_EMOCION + " INTEGER, "
					+ PICTOS_COLUMN_CATEGORIA + " TEXT, "
					+ PICTOS_COLUMN_INTERNO_IMG + " INTEGER, "
					+ PICTOS_COLUMN_LOCUCION + " TEXT, "
					+ PICTOS_COLUMN_INTERNO_LOC + " INTEGER)");
			
			
			//Crear la tabla CONTEXTOS
			db.execSQL("CREATE TABLE " + CONTEXTOS_TABLE_NAME + "("
					+ CONTEXTOS_COLUMN_ID + " INTEGER PRIMARY KEY, "
					+ CONTEXTOS_COLUMN_DESC + " TEXT)");
			
			//Crear la tabla FRASES
			db.execSQL("CREATE TABLE " + FRASES_TABLE_NAME + "("
					+ FRASES_COLUMN_ID + " INTEGER PRIMARY KEY, "
					+ FRASES_COLUMN_LOCUCION + " TEXT, "
					+ FRASES_COLUMN_INTERNO_LOC + " INTEGER)");
			
			//Crear la tabla FRASES_PICTOS
			db.execSQL("CREATE TABLE " + FRASES_PICTOS_TABLE_NAME + "("
					+ FRASES_PICTOS_COLUMN_ID + " INTEGER PRIMARY KEY, "
					+ FRASES_PICTOS_COLUMN_FRASE + " INTEGER, "
					+ FRASES_PICTOS_COLUMN_PICTO + " INTEGER, "
					+ FRASES_PICTOS_COLUMN_ORDEN + " INTEGER)");
			
			//Crear la tabla FRASES_CONTEXTOS
			db.execSQL("CREATE TABLE " + FRASES_CONTEXTOS_TABLE_NAME + "( "
					+ FRASES_CONTEXTOS_COLUMN_ID + " INTEGER PRIMARY KEY, "
					+ FRASES_CONTEXTOS_COLUMN_FRASE + " INTEGER, "
					+ FRASES_CONTEXTOS_COLUMN_CONTEXTO + " INTEGER)");
			
			//Crear la tabla CONTADOR_LOCUCIONES
			db.execSQL("CREATE TABLE " + CONTADOR_LOCUCIONES_TABLE_NAME + "("
					+ CONTADOR_LOCUCIONES_COLUMN_ID + " INTEGER PRIMARY KEY, "
					+ CONTADOR_LOCUCIONES_COLUMN_VALOR + " INTEGER)");
			
		}

		// Se ejecuta cuando hay una nueva versin de la base de datos.
		@Override
		public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
			
			db.execSQL("drop table if exists " + PICTOS_TABLE_NAME);
			db.execSQL("drop table if exists " + CONTEXTOS_TABLE_NAME);
			db.execSQL("drop table if exists " + FRASES_TABLE_NAME);
			db.execSQL("drop table if exists " + FRASES_PICTOS_TABLE_NAME);
			db.execSQL("drop table if exists " + FRASES_CONTEXTOS_TABLE_NAME);
			db.execSQL("drop table if exists " + CONTADOR_LOCUCIONES_TABLE_NAME);
			onCreate(db);
		}
		
	}
	
	//Carga por defecto de las tablas
	public void inicializaPictos(){
		
		ArrayList<Picto> p = new ArrayList<Picto>();
				
		p.add(new Picto(R.drawable.abrir, "ABRIR", false, Constantes.PICTO_CATEGORIA_VERBO, true, "", false));
		p.add(new Picto(R.drawable.aburrir, "ABURRIDO", true, Constantes.PICTO_CATEGORIA_SIN, true, "pi_loc001.3gp", true));
		p.add(new Picto(R.drawable.aplaudir, "APLAUDIR", false, Constantes.PICTO_CATEGORIA_VERBO, true, "", false));
		p.add(new Picto(R.drawable.ascensor, "ASCENSOR", false, Constantes.PICTO_CATEGORIA_OBJETO, true, "", false));
		p.add(new Picto(R.drawable.asustado, "ASUSTADO", true, Constantes.PICTO_CATEGORIA_SIN, true, "pi_loc002.3gp", true));
		p.add(new Picto(R.drawable.boca, "BOCA", false, Constantes.PICTO_CATEGORIA_OBJETO, true, "", false));
		p.add(new Picto(R.drawable.calcetines, "CALCETINES", false, Constantes.PICTO_CATEGORIA_OBJETO, true, "", false));
		p.add(new Picto(R.drawable.madre, "MADRE", false, Constantes.PICTO_CATEGORIA_SUJETO, true, "", false));
		p.add(new Picto(R.drawable.padre, "PADRE", false, Constantes.PICTO_CATEGORIA_SUJETO, true, "", false));
		p.add(new Picto(R.drawable.cansado, "CANSADO", true, Constantes.PICTO_CATEGORIA_SIN, true, "pi_loc003.3gp", true));
		p.add(new Picto(R.drawable.camiseta, "CAMISETA", false, Constantes.PICTO_CATEGORIA_OBJETO, true, "", false));
		p.add(new Picto(R.drawable.colegio, "COLEGIO", false, Constantes.PICTO_CATEGORIA_SUJETO, true, "", false));
		p.add(new Picto(R.drawable.dormir, "DORMIR", false, Constantes.PICTO_CATEGORIA_VERBO, true, "", false));
		p.add(new Picto(R.drawable.gafas, "GAFAS", false, Constantes.PICTO_CATEGORIA_OBJETO, true, "", false));
		p.add(new Picto(R.drawable.triste, "TRISTE", true, Constantes.PICTO_CATEGORIA_SIN, true, "pi_loc004.3gp", true));
		p.add(new Picto(R.drawable.nino, "NIO", false, Constantes.PICTO_CATEGORIA_SUJETO, true, "", false));
		p.add(new Picto(R.drawable.nina, "NIA", false, Constantes.PICTO_CATEGORIA_SUJETO, true, "", false));
		p.add(new Picto(R.drawable.helado, "HELADO", false, Constantes.PICTO_CATEGORIA_OBJETO, true, "", false));
		p.add(new Picto(R.drawable.inodoro, "INODORO", false, Constantes.PICTO_CATEGORIA_OBJETO, true, "", false));
		p.add(new Picto(R.drawable.cepillo_dientes, "CEPILLO DIENTES", false, Constantes.PICTO_CATEGORIA_OBJETO, true, "", false));
		p.add(new Picto(R.drawable.pijama, "PIJAMA", false, Constantes.PICTO_CATEGORIA_OBJETO, true, "", false));
		p.add(new Picto(R.drawable.jugar, "JUGAR", false, Constantes.PICTO_CATEGORIA_VERBO, true, "", false));
		p.add(new Picto(R.drawable.peinar, "PEINAR", false, Constantes.PICTO_CATEGORIA_VERBO, true, "", false));
		p.add(new Picto(R.drawable.enfadar, "ENFADADO", true, Constantes.PICTO_CATEGORIA_SIN, true, "pi_loc005.3gp", true));
		p.add(new Picto(R.drawable.querer, "QUERER", false, Constantes.PICTO_CATEGORIA_VERBO, true, "", false));
		p.add(new Picto(R.drawable.reir, "ALEGRE", true, Constantes.PICTO_CATEGORIA_SIN, true, "pi_loc006.3gp", true));
		p.add(new Picto(R.drawable.pintar, "PINTAR", false, Constantes.PICTO_CATEGORIA_VERBO, true, "", false));
		p.add(new Picto(R.drawable.rechazar, "RECHAZAR", false, Constantes.PICTO_CATEGORIA_VERBO, true, "", false));
		p.add(new Picto(R.drawable.quiero, "QUIERO", false, Constantes.PICTO_CATEGORIA_VERBO, true, "", false));
		p.add(new Picto(R.drawable.leche, "LECHE", false, Constantes.PICTO_CATEGORIA_OBJETO, true, "", false));
		p.add(new Picto(R.drawable.pizza, "PIZZA", false, Constantes.PICTO_CATEGORIA_VERBO, true, "", false));
		p.add(new Picto(R.drawable.sed, "SED", true, Constantes.PICTO_CATEGORIA_SIN, true, "pi_loc007.3gp", true));
		p.add(new Picto(R.drawable.sueno, "SUEO", true, Constantes.PICTO_CATEGORIA_SIN, true, "pi_loc008.3gp", true));
		p.add(new Picto(R.drawable.frio, "FRIO", true, Constantes.PICTO_CATEGORIA_SIN, true, "pi_loc009.3gp", true));
		p.add(new Picto(R.drawable.agradecer, "GRACIAS", true, Constantes.PICTO_CATEGORIA_SIN, true, "pi_loc010.3gp", true));
		p.add(new Picto(R.drawable.calor, "CALOR", true, Constantes.PICTO_CATEGORIA_SIN, true, "pi_loc011.3gp", true));
		p.add(new Picto(R.drawable.vestir, "VESTIR", false, Constantes.PICTO_CATEGORIA_VERBO, true, "", false));
		p.add(new Picto(R.drawable.leer, "LEER", false, Constantes.PICTO_CATEGORIA_VERBO, true, "", false));
		p.add(new Picto(R.drawable.ensuciar, "ENSUCIAR", false, Constantes.PICTO_CATEGORIA_VERBO, true, "", false));
		p.add(new Picto(R.drawable.cuento, "CUENTO", false, Constantes.PICTO_CATEGORIA_OBJETO, true, "", false));
		p.add(new Picto(R.drawable.pelota, "PELOTA", false, Constantes.PICTO_CATEGORIA_OBJETO, true, "", false));
		p.add(new Picto(R.drawable.tobogan, "TOBOGAN", false, Constantes.PICTO_CATEGORIA_OBJETO, true, "", false));
		
		for (int i = 0; i < p.size(); i++){
			savePicto(p.get(i));
		}
		
	}
	
	public void inicializaFrases(){
		ArrayList<Frase> f = new ArrayList<Frase>();
		
		f.add(new Frase(getPictoById(16),getPictoById(29),getPictoById(19),null,true,true,false,"fi_loc001.3gp",true));
		f.add(new Frase(getPictoById(17),getPictoById(25),getPictoById(8),null,true,true,true,"fi_loc002.3gp",true));
		f.add(new Frase(getPictoById(16),getPictoById(29),getPictoById(27),null,true,true,false,"fi_loc003.3gp",true));
		f.add(new Frase(getPictoById(17),getPictoById(29),getPictoById(22),null,true,true,true,"fi_loc004.3gp",true));
		f.add(new Frase(getPictoById(17),getPictoById(29),getPictoById(23),getPictoById(9),true,false,false,"fi_loc005.3gp",true));
		f.add(new Frase(getPictoById(16),getPictoById(29),getPictoById(18),null,true,true,false,"fi_loc006.3gp",true));
		f.add(new Frase(getPictoById(16),getPictoById(29),getPictoById(20),null,true,true,false,"fi_loc007.3gp",true));
		f.add(new Frase(getPictoById(29),getPictoById(9),getPictoById(38),getPictoById(40),true,false,false,"fi_loc008.3gp",true));
		f.add(new Frase(getPictoById(16),getPictoById(39),getPictoById(11),null,true,true,true,"fi_loc009.3gp",true));
		f.add(new Frase(getPictoById(16),getPictoById(37),getPictoById(21),null,true,false,false,"fi_loc010.3gp",true));
		f.add(new Frase(getPictoById(16),getPictoById(29),getPictoById(22),getPictoById(41),false,true,true,"fi_loc011.3gp",true));
		f.add(new Frase(getPictoById(16),getPictoById(29),getPictoById(22),getPictoById(42),false,true,true,"fi_loc012.3gp",true));
		
		
		
		for (int i = 0; i < f.size(); i++){
			saveFrase(f.get(i));
		}
	}
		
	
	public void inicializaContextos(){
		ArrayList<Contexto> c = new ArrayList<Contexto>();
		
		c.add(new Contexto(Constantes.CONTEXTO_CASA));
		c.add(new Contexto(Constantes.CONTEXTO_COLEGIO));
		c.add(new Contexto(Constantes.CONTEXTO_CALLE));
		
		for (int i = 0; i < c.size(); i++){
			saveContexto(c.get(i));
		}
	}
	
	public void cargaContextos(){
		Cursor c = database.rawQuery("SELECT * FROM " + CONTEXTOS_TABLE_NAME, null);
		if (c.moveToFirst()){
			do{
				if (c.getString(c.getColumnIndex(CONTEXTOS_COLUMN_DESC)).equalsIgnoreCase(Constantes.CONTEXTO_CASA))					
					Constantes.CONTEXTO_CASA_ID = c.getLong(c.getColumnIndex(CONTEXTOS_COLUMN_ID));					
				if (c.getString(c.getColumnIndex(CONTEXTOS_COLUMN_DESC)).equalsIgnoreCase(Constantes.CONTEXTO_CALLE)) 
					Constantes.CONTEXTO_CALLE_ID = c.getLong(c.getColumnIndex(CONTEXTOS_COLUMN_ID));
				if (c.getString(c.getColumnIndex(CONTEXTOS_COLUMN_DESC)).equalsIgnoreCase(Constantes.CONTEXTO_COLEGIO)) 
					Constantes.CONTEXTO_COLEGIO_ID = c.getLong(c.getColumnIndex(CONTEXTOS_COLUMN_ID));
			} while (c.moveToNext());
		}
		c.close();
		
	}
	
	
	public void inicializaContadorLocuciones(){
		ContentValues cv = new ContentValues();
		
		cv.put(CONTADOR_LOCUCIONES_COLUMN_VALOR, 1);
		database.insert(CONTADOR_LOCUCIONES_TABLE_NAME, null, cv);
		
	}
	

	
}
