package com.dmolinerm.sac.GUI;

import android.app.Activity;
import android.content.Intent;
import android.database.Cursor;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.GridView;
import android.widget.ImageButton;

import com.dmolinerm.sac.R;
import com.dmolinerm.sac.BLL.SacPictoGaleriaAdapter;
import com.dmolinerm.sac.DAO.SacDatabaseHelper;

public class EmocionesListActivity extends Activity{
	
	private SacPictoGaleriaAdapter pictoAdapter;
	private SacDatabaseHelper databaseHelper;
	private int numPictos, offset;
	private int limite = 9;  // Nmero mximo de pictos a mostrar por pantalla
	private ImageButton btnAtras, btnAdelante;  // Botones para paginar los pictos
	Cursor cursor;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		
		super.onCreate(savedInstanceState);
		setContentView(R.layout.emociones_list);
		
		databaseHelper = new SacDatabaseHelper(this);
		
		// obtenemos el nmero total de pictos a mostrar 
		numPictos = databaseHelper.getEmocionPictosQty();
		// ndice del picto donde empezamos a mostrar (inicialmente 0)
		offset = 0;
		// obtenemos el listado de pictos a mostrar
		cursor = databaseHelper.getEmocionPictos(limite,offset);
		
		pictoAdapter = new SacPictoGaleriaAdapter(this, cursor);
        
		// Cargamos el grid con los pictos obtenidos
        GridView gridEmociones = (GridView) findViewById(R.id.emociones_lista);
		gridEmociones.setAdapter(pictoAdapter);
		
		gridEmociones.setOnItemClickListener(new OnItemClickListener() {
			@Override
			public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
				
				// Si se selecciona uno de los pictos, se muestra en solitario
				Intent i = new Intent(parent.getContext(), EmocionShow.class);
				i.putExtra("id", id);
				startActivity(i);
				
			}
		});
		
		
		btnAtras = (ImageButton) findViewById(R.id.BtnAtras);
		btnAdelante = (ImageButton) findViewById(R.id.BtnAdelante);
		// Incialmente el botn ATRAS es invisible
		btnAtras.setVisibility(ImageButton.INVISIBLE);
		// Si no hay bastantes pictos para paginar, tampoco se muestra el botn ADELANTE.
		if (numPictos <= limite) btnAdelante.setVisibility(ImageButton.INVISIBLE);
		
		btnAdelante.setOnClickListener(new OnClickListener() {
			
			@Override
			public void onClick(View v) {
				//Si se pulsa el botn ADELANTE, se aumenta el offset para mostrar los siguientes pictos.
				offset += limite;
				// Se indica al adaptador que el conjunto de datos ha cambiado, para referescar la pantalla.
				pictoAdapter.changeCursor(databaseHelper.getEmocionPictos(limite, offset));
				pictoAdapter.notifyDataSetChanged();
				if (numPictos <= limite+offset) btnAdelante.setVisibility(ImageButton.INVISIBLE);
				btnAtras.setVisibility(ImageButton.VISIBLE);
			}
		});
		
		btnAtras.setOnClickListener(new OnClickListener() {
			
			@Override
			public void onClick(View v) {
				
				offset -= limite;
				pictoAdapter.changeCursor(databaseHelper.getEmocionPictos(limite, offset));
				pictoAdapter.notifyDataSetChanged();
				if (offset == 0) btnAtras.setVisibility(ImageButton.INVISIBLE);
				btnAdelante.setVisibility(ImageButton.VISIBLE);
			}
		});
	}

	@Override
	protected void onDestroy() {
		
		cursor.close();
		super.onDestroy();
	}
		

}
