package com.dmolinerm.sac.GUI;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.support.v4.app.ListFragment;
import android.view.ContextMenu;
import android.view.ContextMenu.ContextMenuInfo;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView.AdapterContextMenuInfo;

import com.dmolinerm.sac.R;
import com.dmolinerm.sac.BLL.SacFrasesListAdapter;
import com.dmolinerm.sac.DAO.SacDatabaseHelper;

/**
 * @author David Moliner Mateu
 * Listado de las frases existentes
 */
public class FraseListFragment extends ListFragment{
	
	int colorLinea = 0;
	static SacFrasesListAdapter frasesAdapter;
	static SacDatabaseHelper databaseHelper;
	Cursor cursor;
	
	@Override
	public void onCreate(Bundle savedInstanceState) {
		
		super.onCreate(savedInstanceState);
		databaseHelper = new SacDatabaseHelper(getActivity());
		cursor = databaseHelper.getAllFrases();
		
		// establece el adaptador que rellenar la lista
		frasesAdapter = new SacFrasesListAdapter(getActivity(), cursor);
		setListAdapter(frasesAdapter);
	}
	
	
	@Override
	public void onViewCreated(View view, Bundle savedInstanceState) {
		
		super.onViewCreated(view, savedInstanceState);
		setEmptyText(getResources().getString(R.string.no_sentences));
		setHasOptionsMenu(true);
		registerForContextMenu(getListView());
	}


	// Crea el men para la pantalla de la lista de frases
	@Override
	public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
		
		
		super.onCreateOptionsMenu(menu, inflater);
		inflater.inflate(R.menu.menu_add_picto, menu);
	}

	// Seleccin de una opcin de men.
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		
		switch(item.getItemId()){
		// Se selecciona la opcin de aadir una frase
		case R.id.menu_add_picto:
			// Se lanza la pantalla de creacin de frase.
			Intent i = new Intent(getActivity(), FraseEditActivity.class);
			startActivityForResult(i,Constantes.REQUEST_EDIT_CREATE_FRASE);
		}
		return true;
	}

	// Creacin de un men contextual para los elementos de la lista
	@Override
	public void onCreateContextMenu(ContextMenu menu, View v,
			ContextMenuInfo menuInfo) {
		
		super.onCreateContextMenu(menu, v, menuInfo);
		MenuInflater mi = getActivity().getMenuInflater();
		mi.inflate(R.menu.picto_context_menu, menu);
	}


	// Seleccin de una opcin del men contextual
	@Override
	public boolean onContextItemSelected(MenuItem item) {
		
		AdapterContextMenuInfo info = (AdapterContextMenuInfo) item.getMenuInfo();
		switch(item.getItemId()){
		// Opcin editar la frase existente
		case R.id.picto_context_edit:	
			// Se lanza la pantalla de edicin de frase 
			Intent i = new Intent(getActivity(), FraseEditActivity.class);
			// Pasamos la informacin de la frase a editar
			i.putExtra("frase", info.id);
			startActivityForResult(i, Constantes.REQUEST_EDIT_CREATE_FRASE);
			break;
		// Opcin eliminar la frase seleccionada
		case R.id.picto_context_delete:
			// Se muestra cuadro de dilogo para confirmar el borrado.
			DeleteFraseDialog deleteDialog = new DeleteFraseDialog();
			Bundle args = new Bundle();
			args.putLong("id", info.id);
			deleteDialog.setArguments(args);
			deleteDialog.show(getActivity().getSupportFragmentManager(), "DeleteFrase");
			frasesAdapter.changeCursor(databaseHelper.getAllFrases());
		}
		return true;
	}

	// Controla la respuesta de la pantalla de edicin.
	@Override
	public void onActivityResult(int requestCode, int resultCode, Intent data) {
		// Si la creacin de la frase se ha realizado correctamente, refresca la lista.
		if (requestCode == Constantes.REQUEST_EDIT_CREATE_FRASE){
			if (resultCode == Activity.RESULT_OK){
				frasesAdapter.changeCursor(databaseHelper.getAllFrases());
			}
		}
		super.onActivityResult(requestCode, resultCode, data);
	}
	
	// Cuadro de dilogo de confirmacin de borrado.
	public static  class DeleteFraseDialog extends DialogFragment{
		
		private  Bundle args;
		private Activity parent;
		
		@Override
	    public Dialog onCreateDialog(Bundle savedInstanceState) {
	 
			parent = getActivity();
			
	        AlertDialog.Builder builder =
	                new AlertDialog.Builder(parent);
	        args = getArguments();
	 
	        builder.setMessage(getResources().getString(R.string.msg_borrar_frase))
	        .setTitle(getResources().getString(R.string.confirmacion))
	        .setPositiveButton(getResources().getString(R.string.aceptar), new DialogInterface.OnClickListener()  {
	               public void onClick(DialogInterface dialog, int id) {
	            	   		// Acciones a realizar si se confirma el borrado.
	                        databaseHelper.deleteFrase(args.getLong("id"));
	                        frasesAdapter.changeCursor(databaseHelper.getAllFrases());
	                        dialog.cancel();
	                   }
	               })
	        .setNegativeButton(getResources().getString(R.string.cancelar), new DialogInterface.OnClickListener() {
	               public void onClick(DialogInterface dialog, int id) {
	            	   	// Acciones a realizar si se cancela el borrado.
	                        dialog.cancel();
	                   }
	               });
	 
	        return builder.create();
	    }
	}

	@Override
	public void onDestroy() {
		
		cursor.close();
		super.onDestroy();
	}
	
	
	
}
