package com.dmolinerm.sac.GUI;

import java.io.BufferedInputStream;
import java.io.FileDescriptor;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;

import android.app.Activity;
import android.content.res.AssetFileDescriptor;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Color;
import android.media.MediaPlayer;
import android.net.Uri;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ImageView;
import android.widget.LinearLayout;

import com.dmolinerm.sac.R;
import com.dmolinerm.sac.DAO.SacDatabaseHelper;
import com.dmolinerm.sac.entity.Picto;

/**
 * @author David Moliner Mateu
 * Muestra la frase seleccionada de un contexto
 * y reproduce la locucin si la hay
 */
public class FraseShow extends Activity{

	private long idFrase;
	private SacDatabaseHelper databaseHelper;
	private ImageView image1;
	private ImageView borde1;
	private ImageView image2;
	private ImageView borde2;
	private ImageView image3;
	private ImageView borde3;
	private ImageView image4;
	private ImageView borde4;
	private MediaPlayer mPlayer;
	private String mPathFile, locucion = "";
	private boolean interno_loc = false;
	
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		
		super.onCreate(savedInstanceState);
		setContentView(R.layout.frase_simple);
		
		databaseHelper = new SacDatabaseHelper(this);
		
		image1 = (ImageView) findViewById(R.id.frase_row_image1);
		borde1 = (ImageView) findViewById(R.id.frase_row_borde1);
		image2 = (ImageView) findViewById(R.id.frase_row_image2);
		borde2 = (ImageView) findViewById(R.id.frase_row_borde2);
		image3 = (ImageView) findViewById(R.id.frase_row_image3);
		borde3 = (ImageView) findViewById(R.id.frase_row_borde3);
		image4 = (ImageView) findViewById(R.id.frase_row_image4);
		borde4 = (ImageView) findViewById(R.id.frase_row_borde4);
		
		idFrase = getIntent().getLongExtra("frase",0);
		
		mPathFile = getExternalFilesDir("locuciones").getAbsolutePath(); 
		
		inicializaPictos();
		rellenaFrase(idFrase);
		
		// Comprueba si hay locucin y la reproduce
		if (!locucion.equalsIgnoreCase("")){
			mPlayer = new MediaPlayer();
	        try {
	        	if (interno_loc){
	        		AssetFileDescriptor afd = getAssets().openFd(locucion);
	                FileDescriptor fd = afd.getFileDescriptor();
	                mPlayer.setDataSource(fd, afd.getStartOffset(), afd.getLength()); 
	        	} else {
	        		mPlayer.setDataSource(mPathFile + "/" + locucion);
	        	}
	            
	            mPlayer.prepare();
	            mPlayer.start();
	        } catch (IOException e) {
	            //Log.e(LOG_TAG, "prepare() failed");
	        }
		}
		
		
		LinearLayout row = (LinearLayout) findViewById(R.id.sentencia_row);
		
		row.setOnClickListener(new OnClickListener() {
			
			@Override
			public void onClick(View v) {
				
				finish();
			}
		});
					
	}
	
	private void rellenaFrase(Long idFrase){
		Long pictoId;
		Picto picto;
		Cursor fraseCursor;
		
		fraseCursor = databaseHelper.getPictosFromFrase(idFrase);
		if (fraseCursor.moveToFirst()) {
		     //Recorremos el cursor hasta que no haya ms registros
		     do {
		    	 pictoId = fraseCursor.getLong(fraseCursor.getColumnIndex(SacDatabaseHelper.FRASES_PICTOS_COLUMN_PICTO));
		    	 picto = databaseHelper.getPictoById(pictoId);
		    	 switch(fraseCursor.getInt(fraseCursor.getColumnIndex(SacDatabaseHelper.FRASES_PICTOS_COLUMN_ORDEN))){
		    	 	case 1: rellenaPicto(borde1, image1, picto);
		    	 		break;
		    	 	case 2: rellenaPicto(borde2, image2, picto);
		    	 		break;
		    	 	case 3: rellenaPicto(borde3, image3, picto);
		    	 		break;
		    	 	case 4: rellenaPicto(borde4, image4, picto);	    	 
		    	 }
		    	 picto = null;
		    	 locucion = databaseHelper.getLocucionFromFrase(idFrase);
		         interno_loc = databaseHelper.getIsLocucionFraseInterna(idFrase);
		     } while(fraseCursor.moveToNext());
		}
		fraseCursor.close();
		
	}
	
	private void rellenaPicto(ImageView borde, ImageView image, Picto picto){
		if (picto.getSentimiento()){
			borde.setBackgroundColor(Color.parseColor(Constantes.PICTO_EMOCION_COLOR));
		} else {
			borde.setBackgroundResource(Constantes.CATEGORIA_COLOR.get(picto.getCategoria()));
		}
		
		if (picto.isInternoImg()){
			image.setImageResource(picto.getImage());
		} else {
			try{
			String url = "content://media/external/images/media/" + picto.getImage();
			InputStream is = getContentResolver().openInputStream(Uri.parse(url));
			BufferedInputStream bis = new BufferedInputStream(is);
			Bitmap bitmap = Constantes.resizeImage(BitmapFactory.decodeStream(bis), 70, 70);
	    	image.setImageBitmap(bitmap);
			} catch (FileNotFoundException e){
				e.printStackTrace();
			}
		}
	}
	
	private void inicializaPictos(){
		borde1.setBackgroundResource(Constantes.CATEGORIA_COLOR.get(Constantes.PICTO_CATEGORIA_SIN));
		image1.setImageResource(R.drawable.fondo_transparente);
		borde2.setBackgroundResource(Constantes.CATEGORIA_COLOR.get(Constantes.PICTO_CATEGORIA_SIN));
		image2.setImageResource(R.drawable.fondo_transparente);
		borde3.setBackgroundResource(Constantes.CATEGORIA_COLOR.get(Constantes.PICTO_CATEGORIA_SIN));
		image3.setImageResource(R.drawable.fondo_transparente);
		borde4.setBackgroundResource(Constantes.CATEGORIA_COLOR.get(Constantes.PICTO_CATEGORIA_SIN));
		image4.setImageResource(R.drawable.fondo_transparente);
	}


}
