package com.dmolinerm.sac.GUI;

import android.app.Activity;
import android.content.Intent;
import android.database.Cursor;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ImageButton;
import android.widget.ListView;

import com.dmolinerm.sac.R;
import com.dmolinerm.sac.BLL.SacFrasesContextoAdapter;
import com.dmolinerm.sac.DAO.SacDatabaseHelper;

/**
 * @author David Moliner Mateu
 * Muestra las frases asignadas a un contexto.
 */
public class FrasesContextListActivity extends Activity{

	ListView lstFrases;
	int colorLinea = 0;
	private SacFrasesContextoAdapter mAdapter;
	private SacDatabaseHelper databaseHelper;
	private int numFrases, offset;
	private int limite = 4; // Nmero mximo de frases a mostrar por pantalla
	private ImageButton btnAtras, btnAdelante;
	private Bundle args = new Bundle();
	private long idContexto;
	Cursor cursor;

	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		
		super.onCreate(savedInstanceState);
		setContentView(R.layout.contexto_frases);
		
		// recuperamos el contexto seleccionado en la pantalla principal
		args = getIntent().getExtras();
		idContexto = args.getLong("contexto");
		
		databaseHelper = new SacDatabaseHelper(this);
		// Obtenemos el nmero total de frases
		numFrases = databaseHelper.getFrasesContextoQty(idContexto);
		offset = 0;
		// recuperamos las frases a mostrar
		cursor = databaseHelper.getFrasesContexto(limite, offset, idContexto);
		mAdapter = new SacFrasesContextoAdapter(this, cursor);
		
		lstFrases = (ListView) findViewById(R.id.contexto_frases_lista);
		lstFrases.setAdapter(mAdapter);
		
		btnAdelante = (ImageButton) findViewById(R.id.BtnAdelante);
		btnAtras = (ImageButton) findViewById(R.id.BtnAtras);
		btnAtras.setVisibility(ImageButton.INVISIBLE);
		if (numFrases <= limite) btnAdelante.setVisibility(ImageButton.INVISIBLE);
		
		btnAdelante.setOnClickListener(new OnClickListener() {
			// Mostrar las siguientes frases
			@Override
			public void onClick(View v) {
				offset += limite;
				mAdapter.changeCursor(databaseHelper.getFrasesContexto(limite, offset, idContexto));
				mAdapter.notifyDataSetChanged();
				if (numFrases <= limite+offset) btnAdelante.setVisibility(ImageButton.INVISIBLE);
				btnAtras.setVisibility(ImageButton.VISIBLE);				
			}
					
		});
		
		btnAtras.setOnClickListener(new OnClickListener() {
			// Mostrar las anteriores frases
			@Override
			public void onClick(View v) {				
				
				offset -= limite;
				mAdapter.changeCursor(databaseHelper.getFrasesContexto(limite, offset, idContexto));
				mAdapter.notifyDataSetChanged();
				if (offset == 0) btnAtras.setVisibility(ImageButton.INVISIBLE);
				btnAdelante.setVisibility(ImageButton.VISIBLE);
			}
		});
		
		
		// Si se selecciona una frase, se muestra en solitario en la pantalla
		lstFrases.setOnItemClickListener(new OnItemClickListener() {

			@Override
			public void onItemClick(AdapterView<?> parent, View view, int position,
					long id) {
				
				// Llamamos a la pantalla que muestra la frase y le pasamos el id de la frase a mostrar.
				Intent i = new Intent(parent.getContext(), FraseShow.class);
				i.putExtra("frase", id);
				startActivity(i);
				
			}
		
		
		});
		
	}


	@Override
	protected void onDestroy() {
		
		cursor.close();
		super.onDestroy();
	}

	
	
}
