package com.dmolinerm.sac.GUI;

import android.app.Activity;
import android.content.Intent;
import android.content.res.Resources;
import android.database.Cursor;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.GridView;
import android.widget.TabHost;
import android.widget.TabHost.OnTabChangeListener;

import com.dmolinerm.sac.R;
import com.dmolinerm.sac.BLL.SacPictoGaleriaAdapter;
import com.dmolinerm.sac.DAO.SacDatabaseHelper;

/**
 * @author David Moliner Mateu
 * Muestra los pictos disponibles para la construccion de frases
 * Los muestra agrupados por categoria en tres pestaas.
 */
public class GaleriaPictosActivity extends Activity{
	
	private SacPictoGaleriaAdapter pictosObjetosAdapter;
	private SacPictoGaleriaAdapter pictosSujetosAdapter;
	private SacPictoGaleriaAdapter pictosVerbosAdapter;
	private SacDatabaseHelper databaseHelper;
	private Cursor cursorObjetos, cursorSujetos, cursorVerbos = null;

	    @Override
	    public void onCreate(Bundle savedInstanceState) {
	        super.onCreate(savedInstanceState);
	        setContentView(R.layout.galeria_pictos_tab);
	        
	        databaseHelper = new SacDatabaseHelper(this);
	        
	        cursorObjetos = databaseHelper.getCategoriaPictos(Constantes.PICTO_CATEGORIA_OBJETO);
	        cursorSujetos = databaseHelper.getCategoriaPictos(Constantes.PICTO_CATEGORIA_SUJETO);
	        cursorVerbos = databaseHelper.getCategoriaPictos(Constantes.PICTO_CATEGORIA_VERBO);
	        
	       
	        pictosObjetosAdapter = new SacPictoGaleriaAdapter(this, cursorObjetos);
	        pictosSujetosAdapter  = new SacPictoGaleriaAdapter(this, cursorSujetos);
	        pictosVerbosAdapter  = new SacPictoGaleriaAdapter(this, cursorVerbos);
	        
	        Resources res = getResources();
	        
	        // genera un grid para cada pestaa
	        GridView gridPictoObjetos = (GridView) findViewById(R.id.pictos_galeria_objetos);
			gridPictoObjetos.setAdapter(pictosObjetosAdapter);
			GridView gridPictoSujetos = (GridView) findViewById(R.id.pictos_galeria_sujetos);
			gridPictoSujetos.setAdapter(pictosSujetosAdapter);
			GridView gridPictoVerbos = (GridView) findViewById(R.id.pictos_galeria_verbos);
			gridPictoVerbos.setAdapter(pictosVerbosAdapter);
			
			// Configura las pestaas.
	        TabHost tabs=(TabHost)findViewById(android.R.id.tabhost);
	        tabs.setup();
	        
	        TabHost.TabSpec spec=tabs.newTabSpec("mitab1");
	        spec.setContent(R.id.picto_gal_tab_objetos);
	        spec.setIndicator(getResources().getString(R.string.tab_objetos), 
	                        res.getDrawable(android.R.drawable.ic_btn_speak_now));
	        tabs.addTab(spec);
	        
	        spec=tabs.newTabSpec("mitab2");
	        spec.setContent(R.id.picto_gal_tab_sujetos);
	        spec.setIndicator(getResources().getString(R.string.tab_sujetos), 
	                        res.getDrawable(android.R.drawable.ic_dialog_map));
	        tabs.addTab(spec);
	        
	        spec=tabs.newTabSpec("mitab3");
	        spec.setContent(R.id.picto_gal_tab_verbos);
	        spec.setIndicator(getResources().getString(R.string.tab_verbos), 
	                        res.getDrawable(android.R.drawable.ic_input_add));
	        tabs.addTab(spec);
	        
	        tabs.setCurrentTab(0);
	        
	        tabs.setOnTabChangedListener(new OnTabChangeListener() {
	                        public void onTabChanged(String tabId) {
	                                Log.i("AndroidTabsDemo", "Pulsada pestaa: " + tabId);
	                        }
	                });
	        
	        // Si se selecciona un picto, se devuelve a la pantalla de edicin de frases
	        // para asignarlo a la posicin indicada.
	        gridPictoObjetos.setOnItemClickListener(new OnItemClickListener() {

				@Override
				public void onItemClick(AdapterView<?> parent, View view,
						int position, long id) {
					
					Intent intent = getIntent();
					intent.putExtra("picto", id);
					setResult(RESULT_OK, intent);
					finish();
				}
	        	
			});
	        
	        gridPictoSujetos.setOnItemClickListener(new OnItemClickListener() {

				@Override
				public void onItemClick(AdapterView<?> parent, View view,
						int position, long id) {
					
					Intent intent = getIntent();
					intent.putExtra("picto", id);
					setResult(RESULT_OK, intent);
					finish();
				}
	        	
			});
	        
	        gridPictoVerbos.setOnItemClickListener(new OnItemClickListener() {

				@Override
				public void onItemClick(AdapterView<?> parent, View view,
						int position, long id) {
					
					Intent intent = getIntent();
					intent.putExtra("picto", id);
					setResult(RESULT_OK, intent);
					finish();
				}
	        	
			});
	    }

		@Override
		protected void onDestroy() {
			
			cursorObjetos.close();
			cursorSujetos.close();
			cursorVerbos.close();
			super.onDestroy();
		}
	    
	    
	    

}
