package com.dmolinerm.sac.GUI;

import java.io.BufferedInputStream;
import java.io.FileDescriptor;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;

import android.app.Activity;
import android.content.Intent;
import android.content.res.AssetFileDescriptor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.media.MediaPlayer;
import android.media.MediaRecorder;
import android.net.Uri;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.CompoundButton.OnCheckedChangeListener;
import android.widget.ImageView;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;

import com.dmolinerm.sac.R;
import com.dmolinerm.sac.DAO.SacDatabaseHelper;
import com.dmolinerm.sac.entity.Picto;

/**
 * @author David Moliner Mateu
 * Pantalla de edicin/creacin de pictos.
 */
public class PictoEditActivity extends Activity{
	
	private Spinner cmbCategorias;
	private ImageView borde, image;
	public Picto picto;
	private TextView text, text_locucion;
	private CheckBox check;
	private SacDatabaseHelper databaseHelper;
	private Button btnGrabar, btnReproducir, btnGuardar;
	private boolean recording = false;
	private MediaRecorder mRecorder = null;
	private MediaPlayer mPlayer = null;
	public static String mPathFile, mFileName = "";

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		
		super.onCreate(savedInstanceState);
		setContentView(R.layout.edit_picto);
		
		
		ArrayAdapter<String> adaptadorCategorias = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, Constantes.CATEGORIAS);
	
		databaseHelper = new SacDatabaseHelper(this);
		
		mPathFile = getExternalFilesDir("locuciones").getAbsolutePath();
			
		cmbCategorias = (Spinner)findViewById(R.id.categorias_picto);
		borde = (ImageView) findViewById(R.id.picto_edit_borde);
		image = (ImageView) findViewById(R.id.image_picto);
		text = (TextView) findViewById(R.id.nombre_picto);
		check = (CheckBox) findViewById(R.id.emocion_picto);
		btnGuardar = (Button) findViewById(R.id.save_picto);
		btnGrabar = (Button) findViewById(R.id.BtnGrabarPicto);
		btnReproducir = (Button) findViewById(R.id.BtnReproducirPicto);
		text_locucion = (TextView) findViewById(R.id.text_locucion_picto);
		
		adaptadorCategorias.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		cmbCategorias.setAdapter(adaptadorCategorias);
		cmbCategorias.setSelection(0);
		
		// recuperamos los datos del picto a editar.
		Bundle args = getIntent().getExtras();
		if (args != null){
			long pictoId = args.getLong("picto");
			picto = databaseHelper.getPictoById(pictoId);
			String key = picto.getCategoria();
			
			// Se establece el color del borde en funcin de su categoria
			borde.setBackgroundResource(Constantes.CATEGORIA_COLOR.get(key));
			// Comprobamos si la imagen es interna a la aplicacin o est en la galera.
			if (picto.isInternoImg()){
				image.setImageResource(picto.getImage());
			} else {
				try{
					String url = "content://media/external/images/media/" + picto.getImage();
					InputStream is = getContentResolver().openInputStream(Uri.parse(url));
					BufferedInputStream bis = new BufferedInputStream(is);
					Bitmap bitmap = Constantes.resizeImage(BitmapFactory.decodeStream(bis), 70, 70);
			    	image.setImageBitmap(bitmap);
					} catch (FileNotFoundException e){
						e.printStackTrace();
					}
			}
			
			// Si el picto expresa sentimiento, los botones de locucin deben estar disponibles.
			text.setText(picto.getNombre());			
			check.setChecked(picto.getSentimiento());
			if (check.isChecked()){
				text_locucion.setVisibility(TextView.VISIBLE);
				btnGrabar.setVisibility(Button.VISIBLE);
				btnReproducir.setVisibility(Button.VISIBLE);
			} else {
				text_locucion.setVisibility(TextView.INVISIBLE);
				btnGrabar.setVisibility(Button.INVISIBLE);
				btnReproducir.setVisibility(Button.INVISIBLE);
			}
			mFileName = picto.getLocucion();
			cmbCategorias.setSelection(Constantes.CATEGORIA_POS.get(key));
		} else {
			picto = new Picto();
		}
		
		// Si cambiamos la categora, ha de cambiar el color del borde
		cmbCategorias.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
			public void onItemSelected(AdapterView<?> parent, View v, int position, long id){
				borde.setBackgroundResource(Constantes.CATEGORIA_COLOR.get(parent.getItemAtPosition(position)));
			}
			
			public void onNothingSelected(AdapterView<?> parent){
				
			}
		});
		
		
		image.setOnClickListener(new OnClickListener() {
			
			@Override
			public void onClick(View v) {
				// Accedemos a la galera Android para seleccionar una imagen
				Intent intent = new Intent(Intent.ACTION_PICK, android.provider.MediaStore.Images.Media.INTERNAL_CONTENT_URI);
				
				startActivityForResult(intent, Constantes.REQUEST_SELECT_FRASE_IMAGE_1);
			}
		});
		
		
		check.setOnCheckedChangeListener(new OnCheckedChangeListener() {
			
			@Override
			public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
				
				if (isChecked){
					text_locucion.setVisibility(TextView.VISIBLE);
					btnGrabar.setVisibility(Button.VISIBLE);
					btnReproducir.setVisibility(Button.VISIBLE);
				} else {
					text_locucion.setVisibility(TextView.INVISIBLE);
					btnGrabar.setVisibility(Button.INVISIBLE);
					btnReproducir.setVisibility(Button.INVISIBLE);
				}
			}
		});
		
		
		// Grabacin de una locucin.
		btnGrabar.setOnClickListener(new OnClickListener() {
			
			@Override
			public void onClick(View v) {
				
				recording = !recording;
				if (recording){
		
					if ((picto.getLocucion().equalsIgnoreCase("")) || picto.isInternoLoc()){
						mFileName = "loc" + databaseHelper.getNextLocucion() + ".3gp";						
					} else {
						mFileName = picto.getLocucion();
					}
					btnGrabar.setBackgroundResource(R.drawable.blue_button);
					btnGrabar.setText(getResources().getString(R.string.parar));
					mRecorder = new MediaRecorder();
			        mRecorder.setAudioSource(MediaRecorder.AudioSource.MIC);
			        mRecorder.setOutputFormat(MediaRecorder.OutputFormat.THREE_GPP);
			        mRecorder.setOutputFile(mPathFile + "/" + mFileName);
			        mRecorder.setAudioEncoder(MediaRecorder.AudioEncoder.AMR_NB);
			        try {
			            mRecorder.prepare();
			        } catch (IOException e) {
			            //Log.e(LOG_TAG, "prepare() failed");
			        }
			        mRecorder.start();
				} else {
					btnGrabar.setBackgroundResource(R.drawable.red_button);
					btnGrabar.setText(getResources().getString(R.string.grabar));
					mRecorder.stop();
			        mRecorder.release();
			        mRecorder = null;
			        picto.setLocucion(mFileName);
			        picto.setInternoLoc(false);
				}
			}
		});
		
		btnReproducir = (Button) findViewById(R.id.BtnReproducirPicto);
		btnReproducir.setOnClickListener(new OnClickListener() {
			
			@Override
			public void onClick(View v) {
				
				mPlayer = new MediaPlayer();
		        try {
		        	if (picto.isInternoLoc()){
		        		AssetFileDescriptor afd = getAssets().openFd(picto.getLocucion());
		                FileDescriptor fd = afd.getFileDescriptor();
		                mPlayer.setDataSource(fd, afd.getStartOffset(), afd.getLength());		                
		        	} else {
		        		 mPlayer.setDataSource(mPathFile + "/" + mFileName);
		        	}
		           
		            mPlayer.prepare();
		            mPlayer.start();
		        } catch (IOException e) {
		            //Log.e(LOG_TAG, "prepare() failed");
		        }
			}
		});
		
		btnGuardar.setOnClickListener(new OnClickListener() {
			
			@Override
			public void onClick(View v) {
				Intent i = getIntent();
				if (text.getText().toString().equals("")){
					Toast.makeText(getApplicationContext(), getResources().getString(R.string.msg_campo_nombre_vacio), Toast.LENGTH_SHORT).show();
				} else if (picto.getImage() == 0){
					Toast.makeText(getApplicationContext(), getResources().getString(R.string.msg_no_imagen_seleccion), Toast.LENGTH_SHORT).show();
				} else {
					picto.setNombre(text.getText().toString());
					picto.setCategoria(cmbCategorias.getSelectedItem().toString());
					picto.setSentimiento(check.isChecked());
					databaseHelper.savePicto(picto);
					PictoEditActivity.this.setResult(RESULT_OK, i);
					Toast.makeText(getApplicationContext(), getResources().getString(R.string.msg_picto_guarda_ok), Toast.LENGTH_SHORT).show();
					finish();
				}				
			}
		});
		
		
	}	
	

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data){
		if (resultCode == RESULT_OK){
			Uri selectedImage = data.getData();
			InputStream is;
			try {
					
						is = getContentResolver().openInputStream(selectedImage);
						picto.setImage(getImageId(selectedImage));
						picto.setInternoImg(false);
				    	BufferedInputStream bis = new BufferedInputStream(is);
				    	Bitmap bitmap = Constantes.resizeImage(BitmapFactory.decodeStream(bis), 70, 70);
				    	ImageView iv = (ImageView)findViewById(R.id.image_picto);
				    	iv.setImageBitmap(bitmap);		
	
			} catch (FileNotFoundException e) {}
		}
	}
	
	private int getImageId(Uri selectedImage){
		String url = selectedImage.toString();
		String num = url.substring(url.lastIndexOf("/")+1);
		return Integer.parseInt(num);
	}
	
}
