package com.dmolinerm.sac.GUI;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.support.v4.app.ListFragment;
import android.view.ContextMenu;
import android.view.ContextMenu.ContextMenuInfo;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.Toast;
import android.widget.AdapterView.AdapterContextMenuInfo;

import com.dmolinerm.sac.R;
import com.dmolinerm.sac.BLL.SacPictoListAdapter;
import com.dmolinerm.sac.DAO.SacDatabaseHelper;

/**
 * @author David Moliner Mateu
 * Listado de los pictos disponibles en la aplicacin.
 */
public class PictoListFragment extends ListFragment {
	
	static SacPictoListAdapter pictosAdapter;
	static SacDatabaseHelper databaseHelper;
	
	
	@Override
	public void onCreate(Bundle savedInstanceState) {
		
		super.onCreate(savedInstanceState);
		
		databaseHelper = new SacDatabaseHelper(getActivity());

		// Se asigna el adaptador que ha de rellenar la lista
		pictosAdapter = new SacPictoListAdapter(getActivity(), databaseHelper.getAllPictos());
		setListAdapter(pictosAdapter);
	}

	
	@Override
	public void onViewCreated(View view, Bundle savedInstanceState) {
		
		super.onViewCreated(view, savedInstanceState);
		setEmptyText(getResources().getString(R.string.no_pictos));
		setHasOptionsMenu(true);
		registerForContextMenu(getListView());
	}


	// Crea un men para la pantalla
	@Override
	public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
				
		super.onCreateOptionsMenu(menu, inflater);
		inflater.inflate(R.menu.menu_add_picto, menu);
	}

	// Se ha seleccionado una opcin de men.
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		
		switch(item.getItemId()){
		// Muestra la pantalla para la creacin de un picto.
		case R.id.menu_add_picto:
			Intent i = new Intent(getActivity(), PictoEditActivity.class);
			startActivityForResult(i, Constantes.REQUEST_EDIT_CREATE_PICTO);
		}
		return true;
	}

	// se crea un men contextual para los elementos de la lista
	@Override
	public void onCreateContextMenu(ContextMenu menu, View v,
			ContextMenuInfo menuInfo) {
		
		super.onCreateContextMenu(menu, v, menuInfo);
		MenuInflater mi = getActivity().getMenuInflater();
		mi.inflate(R.menu.picto_context_menu, menu);
	}
	
	
	@Override
	public boolean onContextItemSelected(MenuItem item) {

		AdapterContextMenuInfo info = (AdapterContextMenuInfo) item.getMenuInfo();
		switch(item.getItemId()){
		// Se selecciona la opcin de editar un picto
		// Se muestra la pantalla de edicin y se le pasa el id del picto a editar.
		case R.id.picto_context_edit:			
			Intent i = new Intent(getActivity(), PictoEditActivity.class);
			i.putExtra("picto", info.id);
			startActivityForResult(i, Constantes.REQUEST_EDIT_CREATE_PICTO);
			break;
		// Se selecciona la opcin de eliminar un picto.
		// Se muestra un cuadro de dilogo para la confirmacin del borrado. 
		case R.id.picto_context_delete:
			DeletePictoDialog deleteDialog = new DeletePictoDialog();
			Bundle args = new Bundle();
			args.putLong("id", info.id);
			deleteDialog.setArguments(args);
			deleteDialog.show(getActivity().getSupportFragmentManager(), "DeletePicto");
			pictosAdapter.notifyDataSetChanged();
		}
		return true;
	}
	

	@Override
	public void onActivityResult(int requestCode, int resultCode, Intent data) {
		// Si la creacin del picto se ha realizado correctamente.
		// Se refresca la lista.
		if (requestCode == Constantes.REQUEST_EDIT_CREATE_PICTO){
			if (resultCode == Activity.RESULT_OK){
				pictosAdapter.changeCursor(databaseHelper.getAllPictos());
			}
		}
		super.onActivityResult(requestCode, resultCode, data);
	}
	
	
	// Cuadro de dilogo para la confirmacin del borrado.
	public static  class DeletePictoDialog extends DialogFragment{
		
		private  Bundle args;
		private Activity parent;
		
		@Override
	    public Dialog onCreateDialog(Bundle savedInstanceState) {
	 
			parent = getActivity();
			
	        AlertDialog.Builder builder =
	                new AlertDialog.Builder(parent);
	        args = getArguments();
	 
	        builder.setMessage(getResources().getString(R.string.msg_borrar_picto))
	        .setTitle(getResources().getString(R.string.confirmacion))
	        .setPositiveButton(getResources().getString(R.string.aceptar), new DialogInterface.OnClickListener()  {
	        		// Acciones a realizar si se confirma el borrado.
	               public void onClick(DialogInterface dialog, int id) {
	            	   		if (databaseHelper.getFrasesForPicto(args.getLong("id")) > 0){
	            	   			// Si el picto forma parte de alguna frase, no se permite el borrado.
	            	   			Toast.makeText(getActivity().getApplicationContext(), getResources().getString(R.string.msg_no_puede_borrar_picto), Toast.LENGTH_SHORT).show();
	            	   		} else {
	            	   			// Se borrar el picto y se refresca la lista.
	            	   			databaseHelper.deletePicto(args.getLong("id"));
	            	   			pictosAdapter.changeCursor(databaseHelper.getAllPictos());
	            	   		}
	                        dialog.cancel();
	                   }
	               })
	        .setNegativeButton(getResources().getString(R.string.cancelar), new DialogInterface.OnClickListener() {
	               public void onClick(DialogInterface dialog, int id) {
	                        dialog.cancel();
	                   }
	               });
	 
	        return builder.create();
	    }
	}

	

	


}
